import { defineUserConfig } from 'vuepress'
import { defaultTheme } from '@vuepress/theme-default'
import { viteBundler } from '@vuepress/bundler-vite'
import { path } from '@vuepress/utils'
import { registerComponentsPlugin } from '@vuepress/plugin-register-components'

export default defineUserConfig({
  lang: 'en-US',
  title: false,
  description: 'My iGEM Wiki',
  dest: 'public',
  base: "/msp-maastricht/",
  theme: defaultTheme({
    logo: '/images/logo/logo_linear.png',
    navbar: [
      { text: 'Home', link: '/' },
      { 
        text: 'Team',
        children: [
          { text: 'Team', link: '/team' },
          { text: 'Attributions', link: '/attributions/' }
        ]
      },
      { 
        text: 'Project',
        children: [
          { text: 'Contribution', link: '/contribution/' },
          { text: 'Description', link: '/description' },
          { text: 'Engineering', link: '/engineering/'},
          { text: 'Experiments', link: '/experiments/'},
          { text: 'Notebook', link: '/notebook/'},
          { text: 'Results', link: '/results/'}
        ]
      },
      { text: 'Safety', link: '/safety/' },
      { text: 'Human Practices', link: '/human-practices/' },
      { 
        text: 'Awards',
        children: [
          { text: 'Education', link: '/education/' },
          { text: 'Entrepreneurship', link: '/entrepreneurship/' },
          { text: 'Hardware', link: '/hardware/'},
          { text: 'Inclusivity', link: '/inclusivity/'},
          { text: 'Measurement', link: '/measurement/'},
          { text: 'Model', link: '/model/'},
          { text: 'Plant', link: '/plant/'},
          { text: 'Software', link: '/software/'},
          { text: 'Sustainable', link: '/sustainable/'}
        ]
      },
    ],
    sidebar: false,
  }),
  bundler: viteBundler(),
  plugins: [
    registerComponentsPlugin({
      componentsDir: path.resolve(__dirname, './components'),
    }),
  ],
  head: [
    ['link', { rel: 'icon', href: '/images/logo/Natronaut_-_logo__no_text_.png' }],
    ["link", { rel: "preconnect", href: "https://fonts.googleapis.com" }],
    ["link", { rel: "preconnect", href: "https://fonts.gstatic.com", crossorigin: "" }],
    ["link", { rel: "stylesheet", href: "https://fonts.googleapis.com/css2?family=Red+Hat+Display&display=swap" }],
  ],
})
